==> commons-jexl-3.2.1-src.zip: commons-jexl3-3.2.1-src/src/main/java/org/apache/commons/jexl3/internal/MapBuilder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.jexl3.internal;

import java.util.HashMap;
import java.util.Map;
import org.apache.commons.jexl3.JexlArithmetic;

/**
 * Helper class to create map literals.
 */
public class MapBuilder implements JexlArithmetic.MapBuilder {
    /** The map being created. */
    protected final Map<Object, Object> map;

    /**
     * Creates a new builder.
     * @param size the expected map size
     */
    public MapBuilder(final int size) {
        map = new HashMap<Object, Object>(size);
    }

    @Override
    public void put(final Object key, final Object value) {
        map.put(key, value);
    }

    @Override
    public Map<Object,Object> create() {
        return map;
    }
}

==> commons-jexl-3.6.1-src.zip: commons-jexl3-3.6.1-src/src/main/java/org/apache/commons/jexl3/internal/MapBuilder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.jexl3.internal;

import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.Map;

import org.apache.commons.jexl3.JexlArithmetic;

/**
 * Helper class to create map literals.
 */
public class MapBuilder implements JexlArithmetic.MapBuilder {
    /** The map being created. */
    protected final Map<Object, Object> map;

    /**
     * Creates a new builder.
     * @param size the expected map size
     */
    public MapBuilder(final int size) {
        this(size, false);
    }

    /**
     * Creates a new builder.
     * @param size the expected map size
     * @param extended whether the map is extended
     */
    public MapBuilder(final int size, final boolean extended) {
        map = extended? new LinkedHashMap<>(size) : new HashMap<>(size);
    }

    @Override
    public Map<Object,Object> create() {
        return map;
    }

    @Override
    public void put(final Object key, final Object value) {
        map.put(key, value);
    }
}
